@@ -18,7 +18,7 @@ from .utils import (
 )
 
 
-__version__ = '1.3.5'
+__version__ = '1.3.10'
 
 
 versioning_manager = VersioningManager()
@@ -70,6 +70,12 @@ def make_versioned(
         manager.track_association_operations
     )
 
+    sa.event.listen(
+        sa.engine.Engine,
+        'rollback',
+        manager.clear_connection
+    )
+
     sa.event.listen(
         sa.engine.Engine,
         'set_connection_execution_options',
@@ -103,6 +109,12 @@ def remove_versioning(
         manager.track_association_operations
     )
 
+    sa.event.remove(
+        sa.engine.Engine,
+        'rollback',
+        manager.clear_connection
+    )
+
     sa.event.remove(
         sa.engine.Engine,
         'set_connection_execution_options',
