@@ -5,8 +5,7 @@ from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.orm import column_property
 from sqlalchemy_utils.functions import get_declarative_base
 
-from .expression_reflector import VersionExpressionParser
-from .utils import option
+from .utils import adapt_columns, option
 from .version import VersionClassBase
 
 
@@ -18,6 +17,14 @@ def find_closest_versioned_parent(manager, model):
         if class_ in manager.version_class_map:
             return manager.version_class_map[class_]
 
+def versioned_parents(manager, model):
+    """
+    Finds all versioned ancestors for current parent model.
+    """
+    for class_ in model.__mro__:
+        if class_ in manager.version_class_map:
+            yield manager.version_class_map[class_]
+
 
 def get_base_class(manager, model):
     """
@@ -100,6 +107,7 @@ class ModelBuilder(object):
         """
         conditions = []
         foreign_keys = []
+        model_keys = []
         for key, column in sa.inspect(self.model).columns.items():
             if column.primary_key:
                 conditions.append(
@@ -110,6 +118,9 @@ class ModelBuilder(object):
                 foreign_keys.append(
                     getattr(self.version_class, key)
                 )
+                model_keys.append(
+                    getattr(self.model, key)
+                )
 
         # We need to check if versions relation was already set for parent
         # class.
@@ -123,11 +134,18 @@ class ModelBuilder(object):
                     option(self.model, 'transaction_column_name')
                 ),
                 lazy='dynamic',
-                backref=sa.orm.backref(
-                    'version_parent'
-                ),
                 viewonly=True
             )
+            # We must explicitly declare this relationship, instead of
+            # specifying as a backref to the one above, since they are
+            # viewonly=True and SQLAlchemy will warn if using backref.
+            self.version_class.version_parent = sa.orm.relationship(
+                self.model,
+                primaryjoin=sa.and_(*conditions),
+                foreign_keys=model_keys,
+                viewonly=True,
+                uselist=False,
+            )
 
     def build_transaction_relationship(self, tx_class):
         """
@@ -174,8 +192,7 @@ class ModelBuilder(object):
                 if parent.__table__.name != table.name:
                     mapper = sa.inspect(self.model)
 
-                    reflector = VersionExpressionParser()
-                    inherit_condition = reflector(
+                    inherit_condition = adapt_columns(
                         mapper.inherit_condition
                     )
                     tx_column_name = self.manager.options[
@@ -197,12 +214,11 @@ class ModelBuilder(object):
         return args
 
     def get_inherited_denormalized_columns(self, table):
-        parent = find_closest_versioned_parent(self.manager, self.model)
+        parent_models = list(versioned_parents(self.manager, self.model))
         mapper = sa.inspect(self.model)
-
         args = {}
 
-        if parent and not (mapper.single or mapper.concrete):
+        if parent_models and not (mapper.single or mapper.concrete):
             columns = [
                 self.manager.option(self.model, 'operation_type_column_name'),
                 self.manager.option(self.model, 'transaction_column_name')
@@ -214,10 +230,11 @@ class ModelBuilder(object):
                         'end_transaction_column_name'
                     )
                 )
+
             for column in columns:
                 args[column] = column_property(
                     table.c[column],
-                    parent.__table__.c[column]
+                    *[m.__table__.c[column] for m in parent_models]
                 )
         return args
 
@@ -246,11 +263,14 @@ class ModelBuilder(object):
 
         args.update(self.get_inherited_denormalized_columns(table))
 
-        return type(
-            '%sVersion' % self.model.__name__,
-            self.base_classes(),
-            args
-        )
+        if self.manager.options.get('use_module_name', True):
+            name = '%s%sVersion' % (
+                self.model.__module__.title().replace('.', ''),
+                self.model.__name__
+            )
+        else:
+            name = '%sVersion' % (self.model.__name__,)
+        return type(name, self.base_classes(), args)
 
     def __call__(self, table, tx_class):
         """
