@@ -1,3 +1,4 @@
+
 from copy import copy
 import inspect
 import itertools as it
@@ -6,7 +7,7 @@ import warnings
 import sqlalchemy as sa
 from sqlalchemy import create_engine
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.orm import sessionmaker
+from sqlalchemy.orm import sessionmaker, column_property
 from sqlalchemy_continuum import (
     ClassNotVersioned,
     version_class,
@@ -148,6 +149,9 @@ class TestCase(object):
             content = sa.Column(sa.UnicodeText)
             description = sa.Column(sa.UnicodeText)
 
+            # Dynamic column cotaining all text content data
+            fulltext_content = column_property(name + content + description)
+
         class Tag(self.Model):
             __tablename__ = 'tag'
             __versioned__ = copy(self.options)
